nxp-pac

Crates

git

Versions

mimxrt1062

Flavors

UsbOtg2Ctrl

Struct UsbOtg2Ctrl 

#[repr(transparent)]
pub struct UsbOtg2Ctrl(pub u32);
USB OTG2 Control Register

Tuple Fields

0: u32

Implementations

Source

impl UsbOtg2Ctrl

pub const fn over_cur_dis(&self) -> OverCurDis

Disable OTG2 Overcurrent Detection

pub const fn set_over_cur_dis(&mut self, val: OverCurDis)

Disable OTG2 Overcurrent Detection

pub const fn over_cur_pol(&self) -> OverCurPol

OTG2 Polarity of Overcurrent The polarity of OTG2 port overcurrent event

pub const fn set_over_cur_pol(&mut self, val: OverCurPol)

OTG2 Polarity of Overcurrent The polarity of OTG2 port overcurrent event

pub const fn pwr_pol(&self) -> PwrPol

OTG2 Power Polarity This bit should be set according to PMIC Power Pin polarity.

pub const fn set_pwr_pol(&mut self, val: PwrPol)

OTG2 Power Polarity This bit should be set according to PMIC Power Pin polarity.

pub const fn wie(&self) -> Wie

OTG2 Wake-up Interrupt Enable This bit enables or disables the OTG2 wake-up interrupt

pub const fn set_wie(&mut self, val: Wie)

OTG2 Wake-up Interrupt Enable This bit enables or disables the OTG2 wake-up interrupt

pub const fn wkup_sw_en(&self) -> WkupSwEn

OTG2 Software Wake-up Enable

pub const fn set_wkup_sw_en(&mut self, val: WkupSwEn)

OTG2 Software Wake-up Enable

pub const fn wkup_sw(&self) -> WkupSw

OTG2 Software Wake-up

pub const fn set_wkup_sw(&mut self, val: WkupSw)

OTG2 Software Wake-up

pub const fn wkup_id_en(&self) -> WkupIdEn

OTG2 Wake-up on ID change enable

pub const fn set_wkup_id_en(&mut self, val: WkupIdEn)

OTG2 Wake-up on ID change enable

pub const fn wkup_vbus_en(&self) -> WkupVbusEn

OTG2 wake-up on VBUS change enable

pub const fn set_wkup_vbus_en(&mut self, val: WkupVbusEn)

OTG2 wake-up on VBUS change enable

pub const fn wkup_dpdm_en(&self) -> WkupDpdmEn

Wake-up on DPDM change enable

pub const fn set_wkup_dpdm_en(&mut self, val: WkupDpdmEn)

Wake-up on DPDM change enable

pub const fn wir(&self) -> Wir

OTG2 Wake-up Interrupt Request This bit indicates that a wake-up interrupt request is received on the OTG port

pub const fn set_wir(&mut self, val: Wir)

OTG2 Wake-up Interrupt Request This bit indicates that a wake-up interrupt request is received on the OTG port